class ExtraVehicle_resources extends actor;

//#exec OBJ LOAD FILE=TD_hummerMesh.ukx
//#exec OBJ LOAD FILE=TD_HummerStat.usx
//#exec OBJ LOAD FILE=TDHummerTex.utx
//#exec OBJ LOAD FILE=weaponsounds.uax

/*
#######################
Player Animation Poses:
#######################
Since the TD Vehicles have different seat shapes, it is nice to create some new
animation poses for the YARM -and- existing player models.  The file
"SeatMockups_mesh_revXX.ms3d" has a rough shape of each seat at exactly the scale
of the vehicle in UT2k4.  In order to make the animation pose for each skeleton,
simply scale the SeatMockup mesh by the inverse of the scale that each player model
is given in UT2k4 (check the animation browser specifically) and save that as a
new file.  Import it into CharacterFX (by first exporting it from MS3D as MS3D's
ascii text format), then make the poses, and export via the art pipeline (into MS3d,
out as .smd sequence, then convert to .psk via the SMD2PSK utility).

Some notes regarding UT's default player models:
YARM - scaled by 1.5 in the anim browser, rotated by -16384 (0.66 scale applied to the seat mesh set)
Bots - scaled by 0.38 in the anim browser, rotated by -16384 (2.63 scale applied to the seat mesh set)
Females - scaled by 0.44 in the anim browser, rotated by -16384 (2.27 scale applied to the seat mesh set)
Males - scaled by 0.39 in the anim browser, rotated by -16384 (2.564 scale applied to the seat mesh set)
Juggs - scaled by 0.36 in the anim browser, rotated by -16384 (2.77 scale applied to the seat mesh set)
Skaarj - scaled by 0.39 in the anim browser, rotated by -16384 (2.564 scale applied to the seat mesh set)
Aliens - scaled by 0.40 in the anim browser, rotated by -16384 (2.5 scale applied to the seat mesh set)

*/
// New Vehicle Driving Position Animations...
#exec ANIM IMPORT ANIM=MercMaleB_VehicleDriving ANIMFILE=sounds\MercMaleB_VehicleDriving.psa COMPRESS=1 MAXKEYS=999999
#exec ANIM DIGEST ANIM=MercMaleB_VehicleDriving USERAWINFO VERBOSE

#exec ANIM IMPORT ANIM=MercFemaleC_VehicleDriving ANIMFILE=sounds\MercFemaleC_VehicleDriving.psa COMPRESS=1 MAXKEYS=999999
#exec ANIM DIGEST ANIM=MercFemaleC_VehicleDriving USERAWINFO VERBOSE

#exec ANIM IMPORT ANIM=BotUT2kx_VehicleDriving ANIMFILE=sounds\BotUT2kx_VehicleDriving.psa COMPRESS=1 MAXKEYS=999999
#exec ANIM DIGEST ANIM=BotUT2kx_VehicleDriving USERAWINFO VERBOSE

#exec ANIM IMPORT ANIM=JuggChar_VehicleDriving ANIMFILE=sounds\JuggChar_VehicleDriving.psa COMPRESS=1 MAXKEYS=999999
#exec ANIM DIGEST ANIM=JuggChar_VehicleDriving USERAWINFO VERBOSE

#exec ANIM IMPORT ANIM=AlienSkel_VehicleDriving ANIMFILE=sounds\AlienSkel_VehicleDriving.psa COMPRESS=1 MAXKEYS=999999
#exec ANIM DIGEST ANIM=AlienSkel_VehicleDriving USERAWINFO VERBOSE

var() config bool bLogAnimLinks;

// Add this version of AttachDriver to your custom vehicle
simulated function AttachDriver(Pawn P){
	super.AttachDriver(P);
	if( class'ExtraVehicle_resources'.static.LinkDriveAnims(P,self,DriveAnim))
	    P.LoopAnim(DriveAnim,, 0.1);
}

static function bool LinkDriveAnims(Pawn P, Vehicle NewVehicle, optional name DriveAnim){
  local xPawn XP;
  // add the new animation poses if this skeleton does not already have them
  // (like my custom YARM player models already do...
  // animation names to choose from: Driving_JumpSeat, Driving_StickA, Driving_StickB,
  // Driving_Motorcycle, Driving_ATV, Driving_TruckB, Driving_TruckA
  if(!P.HasAnim(DriveAnim)){
      XP = xPawn(P);
      if(XP != none){
         // Aliens
         if (XP.Species == class'SPECIES_Alien'){
            XP.LinkSkelAnim(MeshAnimation'AlienSkel_VehicleDriving');
            if(default.bLogAnimLinks) log("Linked Driving Anims: AlienSkel_VehicleDriving to "$P.GetHumanReadableName());
         }
         // Skaarj
         if (XP.Species == class'SpeciesSkaarj'){
            // this Jugg animation is not an exact match, but since I don't have the
            // Skaarj skeleton it going to have to do for now since the skeletal
            // proportions are at least close, except for the tail...
            XP.LinkSkelAnim(MeshAnimation'JuggChar_VehicleDriving');
            if(default.bLogAnimLinks) log("Linked Driving Anims: JuggChar_VehicleDriving (for Skaarj species) to "$P.GetHumanReadableName());
         }
         // Bots
         else if (XP.Species == class'SPECIES_Bot'){
            if(XP.bIsFemale){
                 XP.LinkSkelAnim(MeshAnimation'MercFemaleC_VehicleDriving');
                 if(default.bLogAnimLinks) log("Linked Driving Anims: MercFemaleC_VehicleDriving (for Bot female) to "$P.GetHumanReadableName());
            }
            else if(XP.GetMeshName() ~="XanRobots.XanM02" || XP.GetMeshName() ~="XanRobots.XanM03"){
                 XP.LinkSkelAnim(MeshAnimation'JuggChar_VehicleDriving');
                 if(default.bLogAnimLinks) log("Linked Driving Anims: JuggChar_VehicleDriving (for Xan Bot) to "$P.GetHumanReadableName());
            }
            else{
                 XP.LinkSkelAnim(MeshAnimation'BotUT2kx_VehicleDriving');
                 if(default.bLogAnimLinks) log("Linked Driving Anims: BotUT2kx_VehicleDriving to "$P.GetHumanReadableName());
            }
         }
         // Juggernauts
         else if (XP.Species == class'SPECIES_Jugg'){
            XP.LinkSkelAnim(MeshAnimation'JuggChar_VehicleDriving');
            if(default.bLogAnimLinks) log("Linked Driving Anims: JuggChar_VehicleDriving to "$P.GetHumanReadableName());
         }
         // Humans
         else if (XP.Species == class'SPECIES_Egypt' || XP.Species == class'SPECIES_Merc'
          || XP.Species == class'SPECIES_Night'){
            if(XP.bIsFemale) XP.LinkSkelAnim(MeshAnimation'MercFemaleC_VehicleDriving');
            else XP.LinkSkelAnim(MeshAnimation'MercMaleB_VehicleDriving');
            if(default.bLogAnimLinks) log("Linked Driving Anims: MercMale/Female_VehicleDriving to "$P.GetHumanReadableName());
         }
      }else{
         P.LinkSkelAnim(MeshAnimation'MercMaleB_VehicleDriving');
         if(default.bLogAnimLinks) log("Linked Driving Anims: MercMaleB_VehicleDriving by default to "$P.GetHumanReadableName());
      }
      return true;
  }
  return false;
}


defaultproperties
{
   bLogAnimLinks=false
}

